@@ -16,7 +16,7 @@ from ipykernel.kernelbase import Kernel
 
 
 # this is the class that will be created if we do comm.create_comm
-class BaseComm(comm.base_comm.BaseComm):
+class BaseComm(comm.base_comm.BaseComm):  # type:ignore[misc]
     """The base class for comms."""
 
     kernel: Optional["Kernel"] = None
@@ -33,12 +33,13 @@ class BaseComm(comm.base_comm.BaseComm):
         if self.kernel is None:
             self.kernel = Kernel.instance()
 
+        assert self.kernel.session is not None
         self.kernel.session.send(
             self.kernel.iopub_socket,
             msg_type,
             content,
             metadata=json_clean(metadata),
-            parent=self.kernel.get_parent("shell"),
+            parent=self.kernel.get_parent(),
             ident=self.topic,
             buffers=buffers,
         )
@@ -66,13 +67,14 @@ class Comm(BaseComm, traitlets.config.LoggingConfigurable):
     def _default_kernel(self):
         if Kernel.initialized():
             return Kernel.instance()
+        return None
 
     @default("comm_id")
     def _default_comm_id(self):
         return uuid.uuid4().hex
 
     def __init__(
-        self, target_name='', data=None, metadata=None, buffers=None, show_warning=True, **kwargs
+        self, target_name="", data=None, metadata=None, buffers=None, show_warning=True, **kwargs
     ):
         """Initialize a comm."""
         if show_warning:
@@ -80,19 +82,18 @@ class Comm(BaseComm, traitlets.config.LoggingConfigurable):
                 "The `ipykernel.comm.Comm` class has been deprecated. Please use the `comm` module instead."
                 "For creating comms, use the function `from comm import create_comm`.",
                 DeprecationWarning,
+                stacklevel=2,
             )
 
         # Handle differing arguments between base classes.
-        had_kernel = 'kernel' in kwargs
-        kernel = kwargs.pop('kernel', None)
+        had_kernel = "kernel" in kwargs
+        kernel = kwargs.pop("kernel", None)
         if target_name:
-            kwargs['target_name'] = target_name
-        BaseComm.__init__(
-            self, data=data, metadata=metadata, buffers=buffers, **kwargs
-        )  # type:ignore[call-arg]
+            kwargs["target_name"] = target_name
+        BaseComm.__init__(self, data=data, metadata=metadata, buffers=buffers, **kwargs)  # type:ignore[call-arg]
         # only re-add kernel if explicitly provided
         if had_kernel:
-            kwargs['kernel'] = kernel
+            kwargs["kernel"] = kernel
         traitlets.config.LoggingConfigurable.__init__(self, **kwargs)
 
 
