@@ -3,6 +3,7 @@ import os
 import re
 import sys
 import typing as t
+from pathlib import Path
 
 import zmq
 from IPython.core.getipython import get_ipython
@@ -20,7 +21,7 @@ from .compiler import get_file_name, get_tmp_directory, get_tmp_hash_seed
 
 try:
     # This import is required to have the next ones working...
-    from debugpy.server import api  # noqa
+    from debugpy.server import api
 
     from _pydevd_bundle import pydevd_frame_utils  # isort: skip
     from _pydevd_bundle.pydevd_suspended_frames import (  # isort: skip
@@ -40,7 +41,7 @@ except Exception as e:
         raise e
 
 
-# Required for backwards compatiblity
+# Required for backwards compatibility
 ROUTING_ID = getattr(zmq, "ROUTING_ID", None) or zmq.IDENTITY
 
 
@@ -179,10 +180,10 @@ class DebugpyMessageQueue:
                 self.tcp_buffer = ""
                 self._reset_tcp_pos()
                 return
-            else:
-                self.tcp_buffer = self.tcp_buffer[self.message_pos + self.message_size :]
-                self.log.debug("QUEUE - slicing tcp_buffer: %s", self.tcp_buffer)
-                self._reset_tcp_pos()
+
+            self.tcp_buffer = self.tcp_buffer[self.message_pos + self.message_size :]
+            self.log.debug("QUEUE - slicing tcp_buffer: %s", self.tcp_buffer)
+            self._reset_tcp_pos()
 
     async def get_message(self):
         """Get a message from the queue."""
@@ -256,8 +257,7 @@ class DebugpyClient:
         await self._wait_for_response()
 
         # 4] Waits for attachResponse and returns it
-        attach_rep = await self._wait_for_response()
-        return attach_rep
+        return await self._wait_for_response()
 
     def get_host_port(self):
         """Get the host debugpy port."""
@@ -294,11 +294,11 @@ class DebugpyClient:
             rep = await self._handle_init_sequence()
             self.wait_for_attach = False
             return rep
-        else:
-            rep = await self._wait_for_response()
-            self.log.debug("DEBUGPYCLIENT - returning:")
-            self.log.debug(rep)
-            return rep
+
+        rep = await self._wait_for_response()
+        self.log.debug("DEBUGPYCLIENT - returning:")
+        self.log.debug(rep)
+        return rep
 
 
 class Debugger:
@@ -363,9 +363,8 @@ class Debugger:
                 self.stopped_queue.put_nowait(msg)
                 # Do not forward the event now, will be done in the handle_stopped_event
                 return
-            else:
-                self.stopped_threads.add(msg["body"]["threadId"])
-                self.event_callback(msg)
+            self.stopped_threads.add(msg["body"]["threadId"])
+            self.event_callback(msg)
         elif msg["event"] == "continued":
             if msg["body"]["allThreadsContinued"]:
                 self.stopped_threads = set()
@@ -380,7 +379,7 @@ class Debugger:
 
     def _build_variables_response(self, request, variables):
         var_list = [var for var in variables if self.accept_variable(var["name"])]
-        reply = {
+        return {
             "seq": request["seq"],
             "type": "response",
             "request_seq": request["seq"],
@@ -388,7 +387,6 @@ class Debugger:
             "command": request["command"],
             "body": {"variables": var_list},
         }
-        return reply
 
     def _accept_stopped_thread(self, thread_name):
         # TODO: identify Thread-2, Thread-3 and Thread-4. These are NOT
@@ -416,8 +414,8 @@ class Debugger:
         """Start the debugger."""
         if not self.debugpy_initialized:
             tmp_dir = get_tmp_directory()
-            if not os.path.exists(tmp_dir):
-                os.makedirs(tmp_dir)
+            if not Path(tmp_dir).exists():
+                Path(tmp_dir).mkdir(parents=True)
             host, port = self.debugpy_client.get_host_port()
             code = "import debugpy;"
             code += 'debugpy.listen(("' + host + '",' + port + "))"
@@ -460,14 +458,13 @@ class Debugger:
         with open(file_name, "w", encoding="utf-8") as f:
             f.write(code)
 
-        reply = {
+        return {
             "type": "response",
             "request_seq": message["seq"],
             "success": True,
             "command": message["command"],
             "body": {"sourcePath": file_name},
         }
-        return reply
 
     async def setBreakpoints(self, message):
         """Handle a set breakpoints message."""
@@ -487,7 +484,7 @@ class Debugger:
         """Handle a source message."""
         reply = {"type": "response", "request_seq": message["seq"], "command": message["command"]}
         source_path = message["arguments"]["source"]["path"]
-        if os.path.isfile(source_path):
+        if Path(source_path).is_file():
             with open(source_path, encoding="utf-8") as f:
                 reply["success"] = True
                 reply["body"] = {"content": f.read()}
@@ -547,7 +544,7 @@ class Debugger:
         cond = variable_name not in forbid_list
         cond = cond and not bool(re.search(r"^_\d", variable_name))
         cond = cond and variable_name[0:2] != "_i"
-        return cond
+        return cond  # noqa: RET504
 
     async def variables(self, message):
         """Handle a variables message."""
@@ -557,12 +554,12 @@ class Debugger:
                 message["arguments"]["variablesReference"]
             )
             return self._build_variables_response(message, variables)
-        else:
-            reply = await self._forward_message(message)
-            # TODO : check start and count arguments work as expected in debugpy
-            reply["body"]["variables"] = [
-                var for var in reply["body"]["variables"] if self.accept_variable(var["name"])
-            ]
+
+        reply = await self._forward_message(message)
+        # TODO : check start and count arguments work as expected in debugpy
+        reply["body"]["variables"] = [
+            var for var in reply["body"]["variables"] if self.accept_variable(var["name"])
+        ]
         return reply
 
     async def attach(self, message):
@@ -580,21 +577,20 @@ class Debugger:
 
     async def configurationDone(self, message):
         """Handle a configuration done message."""
-        reply = {
+        return {
             "seq": message["seq"],
             "type": "response",
             "request_seq": message["seq"],
             "success": True,
             "command": message["command"],
         }
-        return reply
 
     async def debugInfo(self, message):
         """Handle a debug info message."""
         breakpoint_list = []
         for key, value in self.breakpoint_list.items():
             breakpoint_list.append({"source": key, "breakpoints": value})
-        reply = {
+        return {
             "type": "response",
             "request_seq": message["seq"],
             "success": True,
@@ -609,9 +605,9 @@ class Debugger:
                 "stoppedThreads": list(self.stopped_threads),
                 "richRendering": True,
                 "exceptionPaths": ["Python Exceptions"],
+                "copyToGlobals": True,
             },
         }
-        return reply
 
     async def inspectVariables(self, message):
         """Handle an insepct variables message."""
@@ -644,7 +640,7 @@ class Debugger:
         repr_data = {}
         repr_metadata = {}
         if not self.stopped_threads:
-            # The code did not hit a breakpoint, we use the intepreter
+            # The code did not hit a breakpoint, we use the interpreter
             # to get the rich representation of the variable
             result = get_ipython().user_expressions({var_name: var_name})[var_name]
             if result.get("status", "error") == "ok":
@@ -665,7 +661,7 @@ class Debugger:
                 }
             )
             if reply["success"]:
-                repr_data, repr_metadata = eval(reply["body"]["result"], {}, {})  # noqa: S307
+                repr_data, repr_metadata = eval(reply["body"]["result"], {}, {})  # noqa: PGH001
 
         body = {
             "data": repr_data,
@@ -708,8 +704,7 @@ class Debugger:
             if filename and filename.endswith(".py"):
                 mods.append({"id": i, "name": module.__name__, "path": filename})
 
-        reply = {"body": {"modules": mods, "totalModules": len(modules)}}
-        return reply
+        return {"body": {"modules": mods, "totalModules": len(modules)}}
 
     async def process_request(self, message):
         """Process a request."""
